<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>defaultlook</name>
    <message>
        <location filename="defaultlook.ui" line="20"/>
        <location filename="defaultlook.cpp" line="52"/>
        <location filename="defaultlook.cpp" line="464"/>
        <location filename="defaultlook.cpp" line="471"/>
        <location filename="defaultlook.cpp" line="488"/>
        <location filename="defaultlook.cpp" line="499"/>
        <location filename="defaultlook.cpp" line="509"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="54"/>
        <source>Xfce Settings</source>
        <translation>Xfce-Einstellungen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="63"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Leiste anpassen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="77"/>
        <location filename="defaultlook.ui" line="283"/>
        <source>Panel</source>
        <translation>Leiste</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="97"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Fensterverhalten und Tastenkürzel anpassen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="111"/>
        <source>Window Manager</source>
        <translation>Fensterverwaltung</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="131"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Aussehen Ihres Desktops anpassen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="145"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="223"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="234"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="251"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="254"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="261"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="291"/>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="311"/>
        <source>Backup current panel configuration</source>
        <translation>Aktuelle Leistenkonfiguration sichern</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="318"/>
        <source>Restore backup panel configuration</source>
        <translation>Gesicherte Leistenkonfiguration wiederhestellen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="325"/>
        <source>Restore default panel</source>
        <translation>Standardleiste wiederherstellen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="338"/>
        <source>Affects 1st panel</source>
        <translation>Betrifft 1. Leiste</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="345"/>
        <source>Display panel vertically</source>
        <translation>Leiste senkrecht anzeigen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="359"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="364"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="372"/>
        <source>Display panel horizontally</source>
        <translation>Leiste waagerecht anzeigen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="386"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="391"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="399"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;wirksam für ALLE Leisten&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="419"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Fensterknöpfe&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="434"/>
        <location filename="defaultlook.ui" line="537"/>
        <location filename="defaultlook.ui" line="707"/>
        <location filename="defaultlook.ui" line="826"/>
        <location filename="defaultlook.ui" line="868"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="457"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="471"/>
        <source>Theme Options</source>
        <translation>Themenoptionen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="501"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Einige Webseiten-Felder für das Farbschema &quot;dunkel&quot; korrigieren</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="504"/>
        <source>Firefox dark theme tweak</source>
        <translation>Dunkel angepasstes Firefox-Farbschema</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="511"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>HexChat Eingabefeld in dunklem Thema reparieren</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="563"/>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="570"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="580"/>
        <location filename="defaultlook.ui" line="673"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="601"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Einstellungen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="604"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm-Einstellungen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="628"/>
        <source>None</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="633"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) Compositor</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="638"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="646"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Bearbeite compton.conf direkt im Texteditor</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="649"/>
        <source>Edit compton.conf</source>
        <translation>Bearbeite compton.conf</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="680"/>
        <source>Transparency and shadow options</source>
        <translation>Transparenz- und Schattenoptionen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="687"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Starte compton-conf Konfigurationswerkzeug</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="690"/>
        <source>Compton settings</source>
        <translation>Compton-Einstellungen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="743"/>
        <source>Config Options</source>
        <translation>Konfigurationsoptionen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="751"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Lightdm (Login Bildschirm) auf die Systemvoreinstellung zurücksetzen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="758"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Benutzerdefinierten Aktionen in Thunar auf die Systemvoreinstellungen zurücksetzen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="765"/>
        <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
        <translation>Intel Treiber anstelle des voreingestellten &quot;modsetting&quot; Treibers benutzen (Neustart erforderlich)</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="772"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>ANMERKUNG: Die existierende Datei /etc/X11/xorg.conf.d/20-intel.conf wird zur Sicherung in den &lt;HOME&gt;-Ordner verschoben </translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="779"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Option &quot;Tearfree&quot; des AMDGPU-Treibers benutzen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="786"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>ANMERKUNG: Die existierende Datei /etc/X11/xorg.conf.d/20-amd.conf wird zur Sicherung in den &lt;HOME&gt;-Ordner verschoben </translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="793"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Option &quot;Tearfree&quot; des Radeon-Treibers benutzen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="800"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>ANMERKUNG: Die existierende Datei /etc/X11/xorg.conf.d/20-radeon.conf wird zur Sicherung in den &lt;HOME&gt;-Ordner verschoben </translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="840"/>
        <source>Other</source>
        <translation>Anderes</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="848"/>
        <source>Enable single-click on desktop</source>
        <translation>Einfach-Klick auf dem Desktop aktivieren</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="855"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Einfach-Klick im Thunar Dateimanager aktivieren</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="892"/>
        <source>Show systray (notification area) frame</source>
        <translation>Zeige Rahmen um das Benachrichtigungsfeld (Systray)</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="899"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Zeige Fenster von allen Arbeitsflächen in der Leiste</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="906"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Aktiviere Einhängen von internen Laufwerken durch Benutzer ohne root-Rechte</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="913"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Verkürzung langer Dateinamen auf dem Desktop abschalten</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="920"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Ruhezustand im Log-Out Menü zulassen</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="927"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>Hinweis: Für den Ruhezustand wird SWAP &gt;= RAM benötigt.</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="463"/>
        <source>About MX Tweak</source>
        <translation>Über MX Tweak</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="464"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="465"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Anwendung für schnelle Änderungen und Anpassungen an den Voreinstellungen des UI-Themas</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="467"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="468"/>
        <location filename="defaultlook.cpp" line="471"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="469"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="500"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Fertig! Die Änderungen werden nach einem Neustart von Firefox wirksam.</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="510"/>
        <source>This app is Xfce-only</source>
        <translation>Dieses Programm funktioniert nur mit Xfce</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="652"/>
        <source>Panel settings</source>
        <translation>Leisten-Einstellungen</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="653"/>
        <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Die aktuellen Leisten-Einstellungen wurden im versteckten Ordner .restore im Home-Verzeichnis gesichert. (~/.restore/)</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="1070"/>
        <source>Choose a theme set</source>
        <translation>Wählen Sie ein Thema</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="window_buttons.ui" line="14"/>
        <location filename="window_buttons.cpp" line="36"/>
        <source>Window Buttons</source>
        <translation>Fensterknöpfe</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Aussehen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Knopfbeschriftungen anzeigen</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Flache Knöpfe</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Griff anzeigen</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Sortierreihenfolge:</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Zeitstempel</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Titel und Zeitstempel gruppieren</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Fenstertitel</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Titel und Fenstertitel gruppieren</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Keine, ziehen und ablegen ermöglichen</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Verhalten&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Fenstergruppierung:</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Immer</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Mittelklickaktion:</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Fenster schließen</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Fenster verkleinern</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Verkleinerte Fenster in aktueller Arbeitsfläche wiederherstellen</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Fensterrahmen zeichnen, wenn ein Knopf mit der Maus überfahren wird</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Fenster mit dem Mausrad wechseln</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtern&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Fenster aller Arbeitsflächen oder Anzeigenbereiche anzeigen</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Nur verkleinerte Fenster anzeigen</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Fenster von allen Bildschirmen anzeigen</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Popup-Fenster</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Fenster während des Verschiebens</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Deckkraft-Einstellungen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Fensterrahmen</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Zeige Schatten unter Dockfenstern</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Zeige Schatten unter Popup-Fenstern</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Fenster während der Größenänderung</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Zeige Schatten unter gewöhnlichen Fenstern</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Funktionseinstellungen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Zeige beim Durchlauf Fenstervorschauen anstatt Symbole</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Vollbildüberlagerungsfenster sofort anzeigen</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Inaktive Fenster</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Zeichnen mit der vertikalen Austastlücke synchronisieren</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.cpp" line="38"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Xfwm Compositor Einstellungen</translation>
    </message>
</context>
</TS>